import { Inject, Injectable, InjectionToken, NgModule, PLATFORM_ID } from '@angular/core';
import { isPlatformBrowser } from '@angular/common';
import { Router } from '@angular/router';
import { catchError, filter } from 'rxjs/operators';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * @record
 */

/**
 * @record
 */

var OFFLINE_CONFIG_DEFAULT = {
    routeOffline: '/offline',
    routeUnavailable: '/unavailable',
    guardsRedirect: true
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var OFFLINE_CONFIG_ROUTE_OFFLINE = new InjectionToken('offline-config-route-offline');
var OFFLINE_CONFIG_ROUTE_UNAVAILABLE = new InjectionToken('offline-config-route-unavailable');
var OFFLINE_CONFIG_GUARDS_REDIRECT = new InjectionToken('offline-config-guards-redirect');

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var OfflineCatch = (function () {
    function OfflineCatch(router, platformId, routeOffline, routeUnavailable) {
        if (routeOffline === void 0) { routeOffline = OFFLINE_CONFIG_DEFAULT.routeOffline; }
        if (routeUnavailable === void 0) { routeUnavailable = OFFLINE_CONFIG_DEFAULT.routeUnavailable; }
        this.router = router;
        this.platformId = platformId;
        this.routeOffline = routeOffline;
        this.routeUnavailable = routeUnavailable;
        OfflineCatch.instance = this;
    }
    /**
     * @template T
     * @return {?}
     */
    OfflineCatch.catch = /**
     * @template T
     * @return {?}
     */
    function () {
        return catchError(OfflineCatch.catchCallback);
    };
    /**
     * @template T
     * @param {?} error
     * @param {?} caught
     * @return {?}
     */
    OfflineCatch.catchCallback = /**
     * @template T
     * @param {?} error
     * @param {?} caught
     * @return {?}
     */
    function (error, caught) {
        if (!OfflineCatch.instance) {
            console.log('You need to import OfflineModule in your AppModule AND to inject the Offline service in your AppComponent constructor.');
            throw error;
        }
        else {
            var /** @type {?} */ cancel = caught.pipe(filter(function () { return false; }));
            if (isPlatformBrowser(OfflineCatch.instance.platformId) && !navigator.onLine) {
                OfflineCatch.instance.router.navigate([OfflineCatch.instance.routeOffline]);
                return cancel;
            }
            else if (error.status && (error.status >= 500 && error.status < 600)) {
                OfflineCatch.instance.router.navigate([OfflineCatch.instance.routeUnavailable]);
                return cancel;
            }
            else {
                throw error;
            }
        }
    };
    OfflineCatch.instance = null;
    OfflineCatch.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    OfflineCatch.ctorParameters = function () { return [
        { type: Router, },
        { type: undefined, decorators: [{ type: Inject, args: [PLATFORM_ID,] },] },
        { type: undefined, decorators: [{ type: Inject, args: [OFFLINE_CONFIG_ROUTE_OFFLINE,] },] },
        { type: undefined, decorators: [{ type: Inject, args: [OFFLINE_CONFIG_ROUTE_UNAVAILABLE,] },] },
    ]; };
    return OfflineCatch;
}());
var catchOffline = OfflineCatch.catch;

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var OfflineGuard = (function () {
    function OfflineGuard(router, platformId, routeOffline, guardsRedirect) {
        if (routeOffline === void 0) { routeOffline = OFFLINE_CONFIG_DEFAULT.routeOffline; }
        if (guardsRedirect === void 0) { guardsRedirect = OFFLINE_CONFIG_DEFAULT.guardsRedirect; }
        this.router = router;
        this.platformId = platformId;
        this.routeOffline = routeOffline;
        this.guardsRedirect = guardsRedirect;
    }
    /**
     * @return {?}
     */
    OfflineGuard.prototype.isOffline = /**
     * @return {?}
     */
    function () {
        if (isPlatformBrowser(this.platformId) && !navigator.onLine) {
            if (this.guardsRedirect) {
                this.router.navigate([this.routeOffline]);
            }
            return false;
        }
        return true;
    };
    /**
     * @return {?}
     */
    OfflineGuard.prototype.canActivate = /**
     * @return {?}
     */
    function () {
        return this.isOffline();
    };
    /**
     * @return {?}
     */
    OfflineGuard.prototype.canActivateChild = /**
     * @return {?}
     */
    function () {
        return this.isOffline();
    };
    /**
     * @return {?}
     */
    OfflineGuard.prototype.canLoad = /**
     * @return {?}
     */
    function () {
        return this.isOffline();
    };
    OfflineGuard.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    OfflineGuard.ctorParameters = function () { return [
        { type: Router, },
        { type: undefined, decorators: [{ type: Inject, args: [PLATFORM_ID,] },] },
        { type: undefined, decorators: [{ type: Inject, args: [OFFLINE_CONFIG_ROUTE_OFFLINE,] },] },
        { type: undefined, decorators: [{ type: Inject, args: [OFFLINE_CONFIG_GUARDS_REDIRECT,] },] },
    ]; };
    return OfflineGuard;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var ɵ0 = OFFLINE_CONFIG_DEFAULT.routeOffline;
var ɵ1 = OFFLINE_CONFIG_DEFAULT.routeOffline;
var ɵ2 = OFFLINE_CONFIG_DEFAULT.guardsRedirect;
var OfflineModule = (function () {
    function OfflineModule() {
    }
    /**
     * @param {?=} userConfig
     * @return {?}
     */
    OfflineModule.forRoot = /**
     * @param {?=} userConfig
     * @return {?}
     */
    function (userConfig) {
        if (userConfig === void 0) { userConfig = {}; }
        return {
            ngModule: OfflineModule,
            providers: [
                { provide: OFFLINE_CONFIG_ROUTE_OFFLINE, useValue: userConfig.routeOffline },
                { provide: OFFLINE_CONFIG_ROUTE_UNAVAILABLE, useValue: userConfig.routeUnavailable },
                { provide: OFFLINE_CONFIG_GUARDS_REDIRECT, useValue: userConfig.guardsRedirect },
            ]
        };
    };
    OfflineModule.decorators = [
        { type: NgModule, args: [{
                    providers: [
                        { provide: OFFLINE_CONFIG_ROUTE_OFFLINE, useValue: ɵ0 },
                        { provide: OFFLINE_CONFIG_ROUTE_UNAVAILABLE, useValue: ɵ1 },
                        { provide: OFFLINE_CONFIG_GUARDS_REDIRECT, useValue: ɵ2 },
                        OfflineCatch,
                        OfflineGuard,
                    ]
                },] },
    ];
    return OfflineModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Generated bundle index. Do not edit.
 */

export { OfflineCatch, catchOffline, OfflineGuard, OfflineModule, OFFLINE_CONFIG_DEFAULT as ɵa, OFFLINE_CONFIG_GUARDS_REDIRECT as ɵd, OFFLINE_CONFIG_ROUTE_OFFLINE as ɵb, OFFLINE_CONFIG_ROUTE_UNAVAILABLE as ɵc };
//# sourceMappingURL=ngx-pwa-offline.es5.js.map
