import { Inject, Injectable, InjectionToken, NgModule, PLATFORM_ID } from '@angular/core';
import { isPlatformBrowser } from '@angular/common';
import { Router } from '@angular/router';
import { catchError, filter } from 'rxjs/operators';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * @record
 */

/**
 * @record
 */

const OFFLINE_CONFIG_DEFAULT = {
    routeOffline: '/offline',
    routeUnavailable: '/unavailable',
    guardsRedirect: true
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const OFFLINE_CONFIG_ROUTE_OFFLINE = new InjectionToken('offline-config-route-offline');
const OFFLINE_CONFIG_ROUTE_UNAVAILABLE = new InjectionToken('offline-config-route-unavailable');
const OFFLINE_CONFIG_GUARDS_REDIRECT = new InjectionToken('offline-config-guards-redirect');

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class OfflineCatch {
    /**
     * @param {?} router
     * @param {?} platformId
     * @param {?=} routeOffline
     * @param {?=} routeUnavailable
     */
    constructor(router, platformId, routeOffline = OFFLINE_CONFIG_DEFAULT.routeOffline, routeUnavailable = OFFLINE_CONFIG_DEFAULT.routeUnavailable) {
        this.router = router;
        this.platformId = platformId;
        this.routeOffline = routeOffline;
        this.routeUnavailable = routeUnavailable;
        OfflineCatch.instance = this;
    }
    /**
     * @template T
     * @return {?}
     */
    static catch() {
        return catchError(OfflineCatch.catchCallback);
    }
    /**
     * @template T
     * @param {?} error
     * @param {?} caught
     * @return {?}
     */
    static catchCallback(error, caught) {
        if (!OfflineCatch.instance) {
            console.log('You need to import OfflineModule in your AppModule AND to inject the Offline service in your AppComponent constructor.');
            throw error;
        }
        else {
            const /** @type {?} */ cancel = caught.pipe(filter(() => false));
            if (isPlatformBrowser(OfflineCatch.instance.platformId) && !navigator.onLine) {
                OfflineCatch.instance.router.navigate([OfflineCatch.instance.routeOffline]);
                return cancel;
            }
            else if (error.status && (error.status >= 500 && error.status < 600)) {
                OfflineCatch.instance.router.navigate([OfflineCatch.instance.routeUnavailable]);
                return cancel;
            }
            else {
                throw error;
            }
        }
    }
}
OfflineCatch.instance = null;
OfflineCatch.decorators = [
    { type: Injectable },
];
/** @nocollapse */
OfflineCatch.ctorParameters = () => [
    { type: Router, },
    { type: undefined, decorators: [{ type: Inject, args: [PLATFORM_ID,] },] },
    { type: undefined, decorators: [{ type: Inject, args: [OFFLINE_CONFIG_ROUTE_OFFLINE,] },] },
    { type: undefined, decorators: [{ type: Inject, args: [OFFLINE_CONFIG_ROUTE_UNAVAILABLE,] },] },
];
const catchOffline = OfflineCatch.catch;

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class OfflineGuard {
    /**
     * @param {?} router
     * @param {?} platformId
     * @param {?=} routeOffline
     * @param {?=} guardsRedirect
     */
    constructor(router, platformId, routeOffline = OFFLINE_CONFIG_DEFAULT.routeOffline, guardsRedirect = OFFLINE_CONFIG_DEFAULT.guardsRedirect) {
        this.router = router;
        this.platformId = platformId;
        this.routeOffline = routeOffline;
        this.guardsRedirect = guardsRedirect;
    }
    /**
     * @return {?}
     */
    isOffline() {
        if (isPlatformBrowser(this.platformId) && !navigator.onLine) {
            if (this.guardsRedirect) {
                this.router.navigate([this.routeOffline]);
            }
            return false;
        }
        return true;
    }
    /**
     * @return {?}
     */
    canActivate() {
        return this.isOffline();
    }
    /**
     * @return {?}
     */
    canActivateChild() {
        return this.isOffline();
    }
    /**
     * @return {?}
     */
    canLoad() {
        return this.isOffline();
    }
}
OfflineGuard.decorators = [
    { type: Injectable },
];
/** @nocollapse */
OfflineGuard.ctorParameters = () => [
    { type: Router, },
    { type: undefined, decorators: [{ type: Inject, args: [PLATFORM_ID,] },] },
    { type: undefined, decorators: [{ type: Inject, args: [OFFLINE_CONFIG_ROUTE_OFFLINE,] },] },
    { type: undefined, decorators: [{ type: Inject, args: [OFFLINE_CONFIG_GUARDS_REDIRECT,] },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const ɵ0 = OFFLINE_CONFIG_DEFAULT.routeOffline;
const ɵ1 = OFFLINE_CONFIG_DEFAULT.routeOffline;
const ɵ2 = OFFLINE_CONFIG_DEFAULT.guardsRedirect;
class OfflineModule {
    /**
     * @param {?=} userConfig
     * @return {?}
     */
    static forRoot(userConfig = {}) {
        return {
            ngModule: OfflineModule,
            providers: [
                { provide: OFFLINE_CONFIG_ROUTE_OFFLINE, useValue: userConfig.routeOffline },
                { provide: OFFLINE_CONFIG_ROUTE_UNAVAILABLE, useValue: userConfig.routeUnavailable },
                { provide: OFFLINE_CONFIG_GUARDS_REDIRECT, useValue: userConfig.guardsRedirect },
            ]
        };
    }
}
OfflineModule.decorators = [
    { type: NgModule, args: [{
                providers: [
                    { provide: OFFLINE_CONFIG_ROUTE_OFFLINE, useValue: ɵ0 },
                    { provide: OFFLINE_CONFIG_ROUTE_UNAVAILABLE, useValue: ɵ1 },
                    { provide: OFFLINE_CONFIG_GUARDS_REDIRECT, useValue: ɵ2 },
                    OfflineCatch,
                    OfflineGuard,
                ]
            },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Generated bundle index. Do not edit.
 */

export { OfflineCatch, catchOffline, OfflineGuard, OfflineModule, OFFLINE_CONFIG_DEFAULT as ɵa, OFFLINE_CONFIG_GUARDS_REDIRECT as ɵd, OFFLINE_CONFIG_ROUTE_OFFLINE as ɵb, OFFLINE_CONFIG_ROUTE_UNAVAILABLE as ɵc };
//# sourceMappingURL=ngx-pwa-offline.js.map
